import openeo

udf_sgolay = openeo.UDF(
    """

import numpy as np
import xarray as xr
from scipy.signal import savgol_filter
from openeo.udf import XarrayDataCube, inspect

from pathlib import Path
import os
import sys

init_xr = xr.DataArray()
def apply_datacube(cube: XarrayDataCube, context: dict) -> XarrayDataCube:

    array: xarray.DataArray = cube.get_array()
    filled = array.interpolate_na(dim='t')
    smoothed_array = savgol_filter(filled.values, 5, 2, axis=0)
    return XarrayDataCube(
        array=xarray.DataArray(smoothed_array, dims=array.dims, coords=array.coords)
    )
"""
)



from setuptools import setup, find_packages
import os
readme_path = os.path.join(os.path.dirname(__file__), 'README.md')

setup(name="pyeogpr",
      version ="2.2.5",
      description="Python based library to use Earth Observation data to retrieve biophysical maps using Gaussian Process Regression",
      long_description=open(readme_path, 'r').read(),
      long_description_content_type='text/markdown',
      author = "Dávid D.Kovács",
      author_email = "daviddkovacs@gmail.com",
      packages = find_packages(),
      install_requires = ["numpy","openeo","scipy","earthengine-api"])
